@@ -42,6 +42,7 @@ class ClientRequest:
         self.S3_ACCESS_KEY = app.get_conf('s3.access.key', '')
         self.S3_SECRET_KEY = app.get_conf('s3.secret.key', '')
         self.S3_BUCKET = app.get_conf('s3.bucket', '')
+        self.S3_BUCKET_PRIVATE = int(app.get_conf('s3.bucket.private', '0'))
         self.S3_ENDPOINT_URL = app.get_conf('s3.endpoint.url', '')
         if not all([self.S3_ACCESS_KEY, self.S3_SECRET_KEY, self.S3_BUCKET, self.S3_ENDPOINT_URL]):
             klogger.warning('S3 Client missing required parameters, trying COS Client.')
@@ -219,7 +220,8 @@ class ClientRequest:
                     file_url = self._S3_CLIENT.generate_presigned_url('get_object',
                                                                       Params={'Bucket': self.S3_BUCKET,
                                                                               'Key': key},
-                                                                      ExpiresIn=600).split('?')[0]
+                                                                      ExpiresIn=600)
+                    file_url = file_url if self.S3_BUCKET_PRIVATE else file_url.split('?')[0]
                     klogger.info('Upload file cost: {}s'.format(round(time.time() - start, 2)))
                     klogger.info('Upload file success: {}'.format(file_url))
                     return file_url
@@ -279,7 +281,8 @@ class ClientRequest:
                     file_url = self._S3_CLIENT.generate_presigned_url('get_object',
                                                                       Params={'Bucket': self.S3_BUCKET,
                                                                               'Key': key},
-                                                                      ExpiresIn=600).split('?')[0]
+                                                                      ExpiresIn=600)
+                    file_url = file_url if self.S3_BUCKET_PRIVATE else file_url.split('?')[0]
                     klogger.info('Upload file cost: {}s'.format(round(time.time() - start, 2)))
                     klogger.info('Upload file success: {}'.format(file_url))
                     return file_url
